# Trends in atomistic simulation engines

[atomistic.software](https://atomistic.software/#/) aims to track the citation trends of all major atomistic simulation engines.

This is the git source code repository powering the [atomistic.software](https://atomistic.software/#/) website.

## How to cite

You are welcome to cite [atomistic.software](https://atomistic.software/#/) in your scientific work in the following ways:

Talirz, L. *Trends in atomistic simulation engines.* [https://atomistic.software](https://atomistic.software/#/) (2021)
 
## Scope

Working definition of an *atomistic simulation engine*: a piece of software that, given two sets of atomic elements and positions, can compute their (relative) internal energies. 
In almost all cases, engines will also be able to compute the derivative of the energy with respect to the positions, i.e. the forces on the atoms, and thus be able to perform tasks like geometry optimizations or molecular dynamics.
This covers the `DFT`, `WFM`, `QMC`, `TB`, and `FF` categories.

Softwares in the `Spectroscopy` category are not necessarily simulation engines in the above sense, but are able to compute the response of a given atomic structure to an external excitation (via photons, electrons, ...).
## Adding a simulation engine

Contributions of new simulation engines are always welcome!

In order to keep the length of the list manageable, new atomistic simulation engines need to have had at least **one year with 100 citations** or more. 
It is obviously somewhat arbitrary (and is not fulfilled by all historical entries on the list), and may be relaxed over time.

#### Option 1: Suggest addition

If you're not familiar with GitHub or don't have time to add the engine yourself, just [add a comment](https://github.com/ltalirz/atomistic-software/issues/21) with your suggestion.

#### Option 2: Make a pull request

 1. Add code metadata to [`src/data/codes.json`](src/data/codes.json)
 2. (optional) Add citation information to [`src/data/citations.json`](src/data/citations.json)

The second step can also be performed in an automated way by the maintainer of this repository.

## Developing the app

This project was bootstrapped with [Create React App](https://github.com/facebook/create-react-app).

 * `npm start`runs the app in the development mode.
 * `npm test` launches the test runner in the interactive watch mode, see [running tests](https://facebook.github.io/create-react-app/docs/running-tests).
 * `npm run build` builds the app for production to the `build` folder (bundles React and optimizes for performance).
 * `npm run deploy` deploys the app to GitHub pages.

## Acknowledgements

This project was inspired by the ["Major codes in electronic-structure theory, quantum chemistry, and molecular-dynamics"](https://www.nomad-coe.eu/old-pages/externals/codes) collection maintained by the [NOMAD Center of Excellence](https://www.nomad-coe.eu) from 2017-2019.
Thanks go to Luca Ghiringelli for being supportive of this effort to transform the static list into an interactive app and a collaborative project.

The project draws upon further great resources, including:
 * The [Google Scholar](https://scholar.google.com/) search engine for citation counts
 * Wikipedia's [List of quantum chemistry and solid-state physics software](https://en.wikipedia.org/wiki/List_of_quantum_chemistry_and_solid-state_physics_software)
 * Wikipedia's [Comparison of software for molecular mechanics modelling](https://en.wikipedia.org/wiki/Comparison_of_software_for_molecular_mechanics_modeling)
 * SklogWiki's [Materials modelling and computer simulation codes](https://en.wikipedia.org/wiki/Comparison_of_software_for_molecular_mechanics_modeling)

## Contact

leopold.talirz@gmail.com
